@@ -2,18 +2,22 @@
 
 import ast
 import multiprocessing
+import warnings
 
 import geopandas as gpd
 import numpy as np
 import pandas as pd
 import rasterio as rio
-from joblib import Parallel, delayed
-from rasterio import features
-from shapely.geometry import shape
-from rasterio.mask import mask
-import warnings
-from ..util.util import _check_presence_of_crs
 import rasterstats as rs
+from joblib import Parallel, delayed
+from packaging.version import Version
+from rasterio import features
+from rasterio.mask import mask
+from shapely.geometry import shape
+
+from ..util.util import _check_presence_of_crs
+
+GPD_10 = Version(gpd.__version__) >= Version("1.0.0dev")
 
 
 def _chunk_dfs(geoms_to_chunk, n_jobs):
@@ -104,10 +108,12 @@ def extract_raster_features(
     if n_jobs == -1:
         n_jobs = multiprocessing.cpu_count()
     with rio.open(raster_path) as src:
-
-        raster_crs = src.crs.data
+        raster_crs = src.crs.to_dict()
         gdf = gdf.to_crs(raster_crs)
-        geomask = [gdf.unary_union.__geo_interface__]
+        if GPD_10:
+            geomask = [gdf.union_all().__geo_interface__]
+        else:
+            geomask = [gdf.unary_union.__geo_interface__]
 
         out_image, out_transform = mask(
             src, geomask, nodata=nodata, crop=True
